pub struct DateTime {
pub year: i32,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
pub millisecond: u16,
pub offset: Offset,
}Fields
year: i32month: u8day: u8hour: u8minute: u8second: u8millisecond: u16offset: OffsetImplementations
Sourceimpl DateTime
impl DateTime
Sourcepub fn new(
year: i32,
month: u8,
day: u8,
hour: u8,
minute: u8,
second: u8,
millisecond: u16,
) -> Self
pub fn new( year: i32, month: u8, day: u8, hour: u8, minute: u8, second: u8, millisecond: u16, ) -> Self
Returns a new DateTime object, where the offset is set to UTC.
Sourcepub fn new_with_offset(
year: i32,
month: u8,
day: u8,
hour: u8,
minute: u8,
second: u8,
millisecond: u16,
offset: Offset,
) -> Self
pub fn new_with_offset( year: i32, month: u8, day: u8, hour: u8, minute: u8, second: u8, millisecond: u16, offset: Offset, ) -> Self
Returns a new DateTime object, where the offset is set by the user manually.
pub fn month(&self) -> Month
pub fn now() -> Self
pub const fn epoch() -> Self
pub fn now_utc() -> Self