pub struct Fpdf<'a> { /* private fields */ }Expand description
Fpdf is the principal structure for creating a single PDF document.
It holds all the neccessary information for constructing a PDF document, with all images, attachments, bookmarks etc.
Example
use fpdf::Fpdf;
let mut pdf = Fpdf::default();Implementations
Sourceimpl<'a> Fpdf<'a>
impl<'a> Fpdf<'a>
Sourcepub fn new(
orientation: Orientation,
page_size: PageSize,
font_dir: &str,
size_v: UnitVec2,
) -> Self
pub fn new( orientation: Orientation, page_size: PageSize, font_dir: &str, size_v: UnitVec2, ) -> Self
Examples found in repository?
examples/example_set_line_join_style.rs (line 5)
3fn main() {
4 const OFFSET: Unit = Unit::mm(75.0);
5 let mut pdf = Fpdf::new(Orientation::Landscape, PageSize::A4, "", UnitVec2::default());
6 pdf.add_page();
7 let draw = |pdf: &mut Fpdf, cap: &str, join: &str, x0: f64, y0: f64, x1: f64, y1: f64| {
8 let x0 = Unit::mm(x0);
9 let y0 = Unit::mm(y0);
10 let x1 = Unit::mm(x1);
11 let y1 = Unit::mm(y1);
12
13 pdf.set_line_cap_style(cap);
14 pdf.set_line_join_style(join);
15
16 pdf.set_draw_color(RGB::new(0x33, 0x33, 0x33));
17 pdf.set_line_width(Unit::mm(30.0));
18 pdf.move_to(x0, y0);
19 pdf.line_to((x0+x1) / 2.0 + OFFSET, (y0+y1)/2.0);
20 pdf.line_to(x1, y1);
21 pdf.draw_path("D");
22
23 pdf.set_draw_color(RGB::new(0xFF, 0x33, 0x33));
24 pdf.set_line_width(Unit::mm(2.56));
25 pdf.move_to(x0, y0);
26 pdf.line_to((x0+x1)/2.0+OFFSET, (y0+y1)/2.0);
27 pdf.line_to(x1, y1);
28 pdf.draw_path("D");
29 };
30 let mut x = 35.0;
31 let caps = ["butt", "square", "round"];
32 let joins = ["bevel", "miter", "round"];
33 for i in 0..3 {
34 draw(&mut pdf, caps[i], joins[i], x, 50.0, x, 160.0);
35 x += OFFSET.to_mm();
36 }
37 pdf.output_file_and_close("example_set_line_join_style.pdf").unwrap();
38}More examples
examples/example_page_size.rs (lines 4-9)
3fn main() {
4 let mut pdf = Fpdf::new(
5 Orientation::Portrait,
6 PageSize::A4,
7 "",
8 UnitVec2::inch(6.0, 6.0),
9 );
10 pdf.set_margins(Unit::inch(0.5), Unit::inch(1.0), Unit::inch(0.5));
11 pdf.set_font("Times", "", Unit::pt(14.0));
12 pdf.add_page_format(Orientation::Landscape, UnitVec2::inch(3.0, 12.0));
13 pdf.set_xy(Unit::inch(0.5), Unit::inch(1.5));
14 pdf.cell_format(
15 Unit::inch(11.0),
16 Unit::inch(0.2),
17 "12 in times 3 in",
18 "",
19 0,
20 "C",
21 false,
22 0,
23 "",
24 );
25 pdf.add_page();
26 pdf.set_xy(Unit::inch(0.5), Unit::inch(3.0));
27 pdf.cell_format(
28 Unit::inch(5.0),
29 Unit::inch(0.2),
30 "6 in times 6 in",
31 "",
32 0,
33 "C",
34 false,
35 0,
36 "",
37 );
38 pdf.add_page_format(Orientation::Portrait, UnitVec2::inch(3.0, 12.0));
39 pdf.set_xy(Unit::inch(0.5), Unit::inch(6.0));
40 pdf.cell_format(
41 Unit::inch(2.0),
42 Unit::inch(0.2),
43 "3 in times 12 in",
44 "",
45 0,
46 "C",
47 false,
48 0,
49 "",
50 );
51 for i in 0..3 {
52 let page_size = pdf.page_size(i);
53 println!(
54 "{} in times {} in",
55 page_size.width().to_inch(),
56 page_size.height().to_inch()
57 );
58 }
59 pdf.output_file_and_close("example_page_size.pdf").unwrap();
60}examples/example_set_accept_page_break_fn.rs (lines 36-41)
14fn main() {
15 const WIDTH: Unit = Unit::mm(297.0);
16 const GUTTER: usize = 4;
17 const COLS: usize = 3;
18
19 let current_col = Rc::new(RefCell::new(0usize));
20 let y0 = Rc::new(RefCell::new(Unit::mm(0.0)));
21 let col_width: Unit =
22 (WIDTH - MARGIN.mul_untouched(2.0) - Unit::mm(((COLS - 1) * GUTTER) as f64))
23 .div_untouched(COLS as f64);
24 let lorem = LOREM_PARTS.join(" ");
25
26 let set_col = |pdf: &mut Fpdf, col: usize| {
27 let mut current_col = current_col.borrow_mut();
28 *current_col = col;
29 let x = MARGIN
30 + col_width
31 .add_untouched(GUTTER as f64)
32 .mul_untouched(col as f64);
33 pdf.set_left_margin(x);
34 pdf.set_x(x);
35 };
36 let mut pdf = Fpdf::new(
37 Orientation::Landscape,
38 PageSize::A4,
39 "",
40 UnitVec2::default(),
41 );
42 pdf.set_catalog_sort(true);
43 pdf.set_compression(false);
44 pdf.set_header_fn(|pdf| {
45 let title = "fpdf-rs";
46 pdf.set_font("Helvetica", "B", Unit::pt(48.0));
47 let width = pdf.get_string_width(title).add_untouched(6.0);
48 pdf.set_x((WIDTH - width).div_untouched(2.0));
49 pdf.set_text_color(RGB::new(128, 128, 160));
50 pdf.write(Unit::mm(12.0), &title[..4]);
51 pdf.set_text_color(RGB::new(128, 128, 128));
52 pdf.write(Unit::mm(12.0), &title[4..5]);
53 pdf.set_text_color(RGB::new(170, 39, 4));
54 pdf.write(Unit::mm(12.0), &title[5..]);
55 pdf.ln(Unit::mm(20.0));
56 let mut y0 = y0.borrow_mut();
57 *y0 = pdf.get_y();
58 });
59 pdf.set_accept_page_break_fn(|pdf| -> bool {
60 let current_col = {
61 let cc = current_col.borrow();
62 *cc
63 };
64 if current_col < COLS - 1 {
65 set_col(pdf, current_col + 1);
66 let y0 = {
67 let y0 = y0.borrow();
68 *y0
69 };
70 pdf.set_y(y0);
71 false
72 } else {
73 set_col(pdf, 0);
74 true
75 }
76 });
77 pdf.add_page();
78 pdf.set_font("Times", "", Unit::pt(12.0));
79 for i in 0..20 {
80 if i == 1 {
81 pdf.image(
82 "examples/resources/fpdf.png",
83 Unit::negative(),
84 Unit::mm(0.0),
85 UnitVec2::mm(col_width.to_mm(), 0.0),
86 true,
87 ImageOptions::default_png(),
88 0,
89 "",
90 );
91 } else if i == 5 {
92 pdf.image(
93 "examples/resources/rust-ferris.png",
94 Unit::negative(),
95 Unit::mm(0.0),
96 UnitVec2::mm(col_width.to_mm(), 0.0),
97 true,
98 ImageOptions::default_png(),
99 0,
100 "",
101 );
102 }
103 pdf.multi_cell(col_width, Unit::mm(5.0), lorem.as_str(), "", "", false);
104 pdf.ln(Unit::negative());
105 }
106 pdf.output_file_and_close("example_set_accept_page_break_fn.pdf")
107 .unwrap();
108}Sourcepub fn svg_basic_file_parse(svg_file: &str) -> Result<SVGBasic>
pub fn svg_basic_file_parse(svg_file: &str) -> Result<SVGBasic>
Examples found in repository?
examples/example_svg_basic_write.rs (line 23)
13fn main() {
14 const FONT_SIZE: Unit = Unit::pt(16.0);
15 const WIDTH: Unit = Unit::mm(100.0);
16 const SVG_FILE_PATH: &'static str = "examples/resources/drawing.svg";
17
18 let mut pdf = Fpdf::default();
19 pdf.set_font("Times", "", FONT_SIZE);
20 pdf.add_page();
21 pdf.set_margins(Unit::mm(10.0), Unit::mm(10.0), Unit::mm(10.0));
22 pdf.write_basic_html(FONT_SIZE, HTML);
23 let svg_file = Fpdf::svg_basic_file_parse(SVG_FILE_PATH).unwrap();
24 let mut scale = 100.0 / svg_file.width;
25 let scale_y = 30.0 / svg_file.height;
26 if scale > scale_y {
27 scale = scale_y;
28 }
29 pdf.set_line_cap_style("round");
30 pdf.set_line_width(Unit::mm(0.25));
31 pdf.set_draw_color(RGB::new(0, 0, 128));
32 let y = pdf.get_y();
33 pdf.set_xy(Unit::mm(210.0 - scale * svg_file.width) / 2.0, y + 10.0);
34 pdf.svg_basic_write(&svg_file, Unit::mm(scale));
35 pdf.output_file_and_close("example_svg_basic_write.pdf")
36 .unwrap();
37}pub fn deserialize_template(b: Vec<u8>) -> Result<impl Template>